@@ -18,20 +18,22 @@ class HBaseClient(object):
                  file_path=None,
                  server_type=None,
                  connection_num=5,
-                 time_out=15):
+                 time_out=15,
+                 env='test'):
         """
         :param host(str): 指定hbase库ip地址
         :param port(str, int): 指定hbase库端口号,数字形式
         :param file_path(str): 配置文件路径
         :param server_type(str): 指定需要连接的服务器类型(pro/dev)
-        :param connection_num(int)- 连接池中的连接数
-        :param time_out(int)- 获取连接时的最大等待时间
-        :
+        :param connection_num(int): 连接池中的连接数
+        :param time_out(int): 获取连接时的最大等待时间
+        :param env (str): 'test' or 'prd', 由于生产环境与测试环境版本不一致，短暂使用
         """
         self.connection_num = connection_num
         self.time_out = time_out
         self.host = host
         self.port = port
+        self.env = env
 
         if (file_path is not None) & (server_type is not None):
             try:
@@ -66,8 +68,8 @@ class HBaseClient(object):
             host=self.host, 
             port=self.port,
             # Below is a bug fix for hbase version over 2.0
-            transport='framed',  # Default: 'buffered'  <---- Changed.
-            protocol='compact'   # Default: 'binary'    <---- Changed.
+            transport='framed' if self.env == 'test' else 'buffered',  # Default: 'buffered'  <---- Changed.
+            protocol='compact' if self.env == 'test' else 'binary'   # Default: 'binary'    <---- Changed.
         )
 
     @reconnection
